@@ -1,12 +1,17 @@
 """Contains UI methods for Nginx operations."""
 import logging
+from typing import Iterable
+from typing import List
+from typing import Optional
+
+from certbot_nginx._internal.obj import VirtualHost
 
 from certbot.display import util as display_util
 
 logger = logging.getLogger(__name__)
 
 
-def select_vhost_multiple(vhosts):
+def select_vhost_multiple(vhosts: Optional[Iterable[VirtualHost]]) -> List[VirtualHost]:
     """Select multiple Vhosts to install the certificate for
     :param vhosts: Available Nginx VirtualHosts
     :type vhosts: :class:`list` of type `~obj.Vhost`
@@ -28,7 +33,7 @@ def select_vhost_multiple(vhosts):
     return []
 
 
-def _reversemap_vhosts(names, vhosts):
+def _reversemap_vhosts(names: Iterable[str], vhosts: Iterable[VirtualHost]) -> List[VirtualHost]:
     """Helper function for select_vhost_multiple for mapping string
     representations back to actual vhost objects"""
     return_vhosts = []
